
Logging implemented on the server-side
-------

**Description:**

Logging should always be implemented on the server-side since an attacker otherwise 
manipulate the functionality and erase his traces.


**Solution:**

Verify that all logging controls are implemented on the server-side.
